==> request-tracker4_4.4.6+dfsg.orig-third-party-source.tar.gz: rt-4.4.6/devel/third-party/ckeditor-src/plugins/table/lang/sv.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'sv', {
	border: 'Kantstorlek',
	caption: 'Rubrik',
	cell: {
		menu: 'Cell',
		insertBefore: 'Lägg till cell före',
		insertAfter: 'Lägg till cell efter',
		deleteCell: 'Radera celler',
		merge: 'Sammanfoga celler',
		mergeRight: 'Sammanfoga höger',
		mergeDown: 'Sammanfoga ner',
		splitHorizontal: 'Dela cell horisontellt',
		splitVertical: 'Dela cell vertikalt',
		title: 'Egenskaper för cell',
		cellType: 'Celltyp',
		rowSpan: 'Rad spann',
		colSpan: 'Kolumnen spann',
		wordWrap: 'Radbrytning',
		hAlign: 'Horisontell justering',
		vAlign: 'Vertikal justering',
		alignBaseline: 'Baslinje',
		bgColor: 'Bakgrundsfärg',
		borderColor: 'Ramfärg',
		data: 'Data',
		header: 'Rubrik',
		yes: 'Ja',
		no: 'Nej',
		invalidWidth: 'Cellens bredd måste vara ett nummer.',
		invalidHeight: 'Cellens höjd måste vara ett nummer.',
		invalidRowSpan: 'Radutvidgning måste vara ett heltal.',
		invalidColSpan: 'Kolumn måste vara ett heltal.',
		chooseColor: 'Välj'
	},
	cellPad: 'Cellutfyllnad',
	cellSpace: 'Cellavstånd',
	column: {
		menu: 'Kolumn',
		insertBefore: 'Lägg till kolumn före',
		insertAfter: 'Lägg till kolumn efter',
		deleteColumn: 'Radera kolumn'
	},
	columns: 'Kolumner',
	deleteTable: 'Radera tabell',
	headers: 'Rubriker',
	headersBoth: 'Båda',
	headersColumn: 'Första kolumnen',
	headersNone: 'Ingen',
	headersRow: 'Första raden',
	invalidBorder: 'Ram måste vara ett nummer.',
	invalidCellPadding: 'Luft i cell måste vara ett nummer.',
	invalidCellSpacing: 'Luft i cell måste vara ett nummer.',
	invalidCols: 'Antal kolumner måste vara ett nummer större än 0.',
	invalidHeight: 'Tabellens höjd måste vara ett nummer.',
	invalidRows: 'Antal rader måste vara större än 0.',
	invalidWidth: 'Tabell måste vara ett nummer.',
	menu: 'Tabellegenskaper',
	row: {
		menu: 'Rad',
		insertBefore: 'Lägg till rad före',
		insertAfter: 'Lägg till rad efter',
		deleteRow: 'Radera rad'
	},
	rows: 'Rader',
	summary: 'Sammanfattning',
	title: 'Tabellegenskaper',
	toolbar: 'Tabell',
	widthPc: 'procent',
	widthPx: 'pixlar',
	widthUnit: 'enhet bredd'
} );

==> request-tracker5_5.0.7+dfsg.orig-third-party-source.tar.gz: rt-5.0.7/devel/third-party/ckeditor-src/plugins/table/lang/sv.js <==
/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'sv', {
	border: 'Kantstorlek',
	caption: 'Rubrik',
	cell: {
		menu: 'Cell',
		insertBefore: 'Lägg till cell före',
		insertAfter: 'Lägg till cell efter',
		deleteCell: 'Radera celler',
		merge: 'Sammanfoga celler',
		mergeRight: 'Sammanfoga höger',
		mergeDown: 'Sammanfoga ner',
		splitHorizontal: 'Dela cell horisontellt',
		splitVertical: 'Dela cell vertikalt',
		title: 'Egenskaper för cell',
		cellType: 'Celltyp',
		rowSpan: 'Rad spann',
		colSpan: 'Kolumnen spann',
		wordWrap: 'Radbrytning',
		hAlign: 'Horisontell justering',
		vAlign: 'Vertikal justering',
		alignBaseline: 'Baslinje',
		bgColor: 'Bakgrundsfärg',
		borderColor: 'Ramfärg',
		data: 'Data',
		header: 'Rubrik',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Ja',
		no: 'Nej',
		invalidWidth: 'Cellens bredd måste vara ett nummer.',
		invalidHeight: 'Cellens höjd måste vara ett nummer.',
		invalidRowSpan: 'Radutvidgning måste vara ett heltal.',
		invalidColSpan: 'Kolumn måste vara ett heltal.',
		chooseColor: 'Välj'
	},
	cellPad: 'Cellutfyllnad',
	cellSpace: 'Cellavstånd',
	column: {
		menu: 'Kolumn',
		insertBefore: 'Lägg till kolumn före',
		insertAfter: 'Lägg till kolumn efter',
		deleteColumn: 'Radera kolumn'
	},
	columns: 'Kolumner',
	deleteTable: 'Radera tabell',
	headers: 'Rubriker',
	headersBoth: 'Båda',
	headersColumn: 'Första kolumnen',
	headersNone: 'Ingen',
	headersRow: 'Första raden',
	heightUnit: 'Enhetshöjd',
	invalidBorder: 'Ram måste vara ett nummer.',
	invalidCellPadding: 'Luft i cell måste vara ett nummer.',
	invalidCellSpacing: 'Luft i cell måste vara ett nummer.',
	invalidCols: 'Antal kolumner måste vara ett nummer större än 0.',
	invalidHeight: 'Tabellens höjd måste vara ett nummer.',
	invalidRows: 'Antal rader måste vara större än 0.',
	invalidWidth: 'Tabell måste vara ett nummer.',
	menu: 'Tabellegenskaper',
	row: {
		menu: 'Rad',
		insertBefore: 'Lägg till rad före',
		insertAfter: 'Lägg till rad efter',
		deleteRow: 'Radera rad'
	},
	rows: 'Rader',
	summary: 'Sammanfattning',
	title: 'Tabellegenskaper',
	toolbar: 'Tabell',
	widthPc: 'procent',
	widthPx: 'pixlar',
	widthUnit: 'enhet bredd'
} );
